Settings object API
===================

This page documents the :class:`Settings` object and its API.

.. autoclass:: ycsettings.settings.Settings
    :members:
    :special-members:
    :exclude-members: __dict__, __weakref__

.. autofunction:: ycsettings.settings.parse_n_jobs
